@@ -5,8 +5,8 @@ from feii.cli import ErrorCLI
 
 @click.command(
   cls=ErrorCLI,
-  short_help='Fix ILM error.',
+  short_help='Correcting errors in indexes.',
   epilog="Run 'feii error COMMAND --help' for more information on a command."
 )
 def cli():
-  """Fix ILM error"""
+  """Correcting errors in indexes"""
