@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 import click
-from feii.main import class_structure, class_log, logging_level, updating_variables, generating_variables, generating_variables_for_delete, deleting_unnecessary_variables
+from feii.main import class_structure, class_log, logging_level, updating_variables, generating_variables_for_indices, generating_variables_for_delete, deleting_unnecessary_variables
 from feii.delete import Delete
 
 class_delete = Delete()
@@ -30,7 +30,7 @@ def start_check_mode_delete_last_indexes(check_mode):
   help='Set the logging level ("debug"|"info"|"warning"|"error"|"critical")'
 )
 @click.option(
-  '-p', '--path_to_file',
+  '-P', '--path-to-file',
   default='',
   expose_value=True,
   help='path'
@@ -43,7 +43,7 @@ def cli(check_mode, log_level, path_to_file):
 
   updating_variables(path_to_file)
 
-  generating_variables()
+  generating_variables_for_indices()
   generating_variables_for_delete()
   deleting_unnecessary_variables()
 
